# -*- encoding: utf-8 -*-
"""
@文件        :GmApp.py
@说明        :
@时间        :2024/11/27 18:40:17
@作者        :Zack
@版本        :1.0
"""
from dataclasses import dataclass

from gmscaffold.base.dataclass import BaseData


@dataclass
class GmAppData(BaseData):
    """ """
